behavior missionTimer
{
  timeOut = 10800;
}
#
# Depth Envelope
#
behavior depthEnvelope
{
  minDepth = 0; #Meters
  maxDepth = 1020; #Meters
  abortDepth = 1025; #Meters
  minAltitude = 40.0; #Meters
  abortAltitude = 30.0; #Meters
}
# acquire gps fix
behavior getgps {
duration = 300;
minHits = 10;
abortOnTimeout = True;
}
behavior ascend
{
  duration = 200; #Seconds
  horizontalMode = rudder; #Mode
  horizontal = -3; #Degrees; 
  pitch = 30; #Degrees
  speed = 1.5; #Meters/sec
  endDepth = 2; #Meters
}
behavior CARL
{
  id = 108;
  duration = 1;
  record = 0;
  homeIris = 1;
  lightSwitch = 0;
}
behavior ascend
{
  duration = 2000; #Seconds
  horizontalMode = rudder; #Mode
  horizontal = -3; #Degrees; 
  pitch = 30; #Degrees
  speed = 1.5; #Meters/sec
  endDepth = 5; #Meters
}
behavior CARL
{
  id = 110;
  clipname = 1;
  duration = 1;
  record = 1;
  fstop = 31;
}
#14. End 5.
behavior waypoint
{
  duration = 878;
  depth = 1000;
  speed = 1.1;
  latitude = 36.696318;
  longitude = -122.053721;
}
#13. Turn, stabilize, setup.
behavior waypoint
{
  duration = 326;
  depth = 1000;
  speed = 1.5;
  latitude = 36.696318;
  longitude = -122.049800;
}
behavior CARL
{
  id = 110;
  lightSwitch = 1;
  fstop = 31;
  clipname = 1;
  duration = 1;
  record = 1;
}
#12. Dive.
behavior waypoint
{
  duration = 385;
  depth = 1000;
  speed = 1.5;
  latitude = 36.696318;
  longitude = -122.048343;
}
behavior CARL
{
  id = 108;
  duration = 1;
  record = 0;
  homeIris = 1;
  lightSwitch = 0;
}
#11.  End 4
behavior waypoint
{
  duration = 870;
  depth = 900;
  speed = 1.1;
  latitude = 36.697009;
  longitude = -122.049837;
}
#10. Turn, stabilize, set up.
behavior waypoint
{
  duration = 227;
  depth = 900;
  speed = 1.5;
  latitude = 36.697039;
  longitude = -122.053721;
}
behavior CARL
{
  id = 110;
  lightSwitch = 1;
  fstop = 31;
  clipname = 1;
  duration = 1;
  record = 1;
}
#9. Dive. 
behavior waypoint
{
  duration = 319;
  depth = 900;
  speed = 1.5;
  latitude = 36.697039;
  longitude = -122.054729;
}
behavior CARL
{
  id = 108;
  duration = 1;
  record = 0;
  homeIris = 1;
  lightSwitch = 0;
}
#8. End 3.
behavior waypoint
{
  duration = 878;
  depth = 800;
  speed = 1.1;
  latitude = 36.696227;
  longitude = -122.053721;
}
#Seven.  Turn, stabilize, and set up.
behavior waypoint
{
  duration = 326;
  depth = 800;
  speed = 1.5;
  latitude = 36.696227;
  longitude = -122.049800;
}
behavior CARL
{
  id = 110;
  lightSwitch = 1;
  fstop = 31;
  clipname = 1;
  duration = 1;
  record = 1;
}
#Six. Dive.
behavior waypoint
{
  duration = 385;
  depth = 800;
  speed = 1.5;
  latitude = 36.696227;
  longitude = -122.048343;
}
behavior CARL
{
  id = 108;
  duration = 1;
  record = 0;
  homeIris = 1;
  lightSwitch = 0;
}
#Five End 2
behavior waypoint
{
  duration = 870;
  depth = 700;
  speed = 1.1;
  latitude = 36.696918;
  longitude = -122.049837;
}
#Four. Turn, stabilize, and set up for the next segment.
behavior waypoint
{
  duration = 227;
  depth = 700;
  speed = 1.5;
  latitude = 36.696948;
  longitude = -122.053721;
}
behavior CARL
{
  id = 110;
  lightSwitch = 1;
  fstop = 31;
  clipname = 1;
  duration = 1;
  record = 1;
}
#Three.  Descend.  
behavior waypoint
{
  duration = 319;
  depth = 700;
  speed = 1.5;
  latitude = 36.696948;
  longitude = -122.054729;
}
behavior CARL
{
  id = 108;
  duration = 1;
  record = 0;
  lightSwitch = 0;
  homeIris = 1;
}
#Two.  End Segment.
behavior waypoint
{
  duration = 878;
  depth = 600;
  speed = 1.1;
  latitude = 36.696137;
  longitude = -122.053721;
}
#19. Turn, stabilize, setup.
behavior waypoint
{
  duration = 326;
  depth = 600;
  speed = 1.5;
  latitude = 36.696137;
  longitude = -122.049800;
}
behavior CARL
{
  id = 110;
  lightSwitch = 1;
  fstop = 31;
  clipname = 1;
  duration = 1;
  record = 1;
}
#18. Dive.
behavior waypoint
{
  duration = 385;
  depth = 600;
  speed = 1.5;
  latitude = 36.696137;
  longitude = -122.048343;
}
behavior CARL
{
  id = 108;
  duration = 1;
  record = 0;
  homeIris = 1;
  lightSwitch = 0;
}
#17. End 6.
behavior waypoint
{
  duration = 870;
  depth = 500;
  speed = 1.1;
  latitude = 36.696828;
  longitude = -122.049837;
}
#16. Turn, stabilize, setup.
behavior waypoint
{
  duration = 227;
  depth = 500;
  speed = 1.5;
  latitude = 36.696858;
  longitude = -122.053721;
}
behavior CARL
{
  id = 110;
  lightSwitch = 1;
  fstop = 31;
  clipname = 1;
  duration = 1;
  record = 1;
}
#15. Dive.
behavior waypoint
{
  duration = 319;
  depth = 500;
  speed = 1.5;
  latitude = 36.696858;
  longitude = -122.054729;
}
behavior CARL
{
  id = 108;
  duration = 1;
  record = 0;
  homeIris = 1;
  lightSwitch = 0;
}
#14. End 5.
behavior waypoint
{
  duration = 878;
  depth = 400;
  speed = 1.1;
  latitude = 36.696047;
  longitude = -122.053721;
}
#13. Turn, stabilize, setup.
behavior waypoint
{
  duration = 326;
  depth = 400;
  speed = 1.5;
  latitude = 36.696047;
  longitude = -122.049800;
}
behavior CARL
{
  id = 110;
  lightSwitch = 1;
  fstop = 31;
  clipname = 1;
  duration = 1;
  record = 1;
}
#12. Dive.
behavior waypoint
{
  duration = 385;
  depth = 400;
  speed = 1.5;
  latitude = 36.696047;
  longitude = -122.048343;
}
behavior CARL
{
  id = 108;
  duration = 1;
  record = 0;
  homeIris = 1;
  lightSwitch = 0;
}
#11.  End 4
behavior waypoint
{
  duration = 870;
  depth = 300;
  speed = 1.1;
  latitude = 36.696738;
  longitude = -122.049837;
}
#10. Turn, stabilize, set up.
behavior waypoint
{
  duration = 226;
  depth = 300;
  speed = 1.5;
  latitude = 36.696768;
  longitude = -122.053721;
}
behavior CARL
{
  id = 110;
  lightSwitch = 1;
  fstop = 31;
  clipname = 1;
  duration = 1;
  record = 1;
}
#9. Dive. 
behavior waypoint
{
  duration = 319;
  depth = 300;
  speed = 1.5;
  latitude = 36.696768;
  longitude = -122.054729;
}
behavior CARL
{
  id = 108;
  duration = 1;
  record = 0;
  homeIris = 1;
  lightSwitch = 0;
}
#8. End 3.
behavior waypoint
{
  duration = 877;
  depth = 200;
  speed = 1.1;
  latitude = 36.695957;
  longitude = -122.053721;
}
#Seven.  Turn, stabilize, and set up.
behavior waypoint
{
  duration = 326;
  depth = 200;
  speed = 1.5;
  latitude = 36.695957;
  longitude = -122.049800;
}
behavior CARL
{
  id = 110;
  lightSwitch = 1;
  fstop = 31;
  clipname = 1;
  duration = 1;
  record = 1;
}
#Six. Dive.
behavior waypoint
{
  duration = 385;
  depth = 200;
  speed = 1.5;
  latitude = 36.695957;
  longitude = -122.048343;
}
behavior CARL
{
  id = 108;
  duration = 1;
  record = 0;
  homeIris = 1;
  lightSwitch = 0;
}
#Five End 2
behavior waypoint
{
  duration = 870;
  depth = 100;
  speed = 1.1;
  latitude = 36.696648;
  longitude = -122.049837;
}
#Four. Turn, stabilize, and set up for the next segment.
behavior waypoint
{
  duration = 226;
  depth = 100;
  speed = 1.5;
  latitude = 36.696678;
  longitude = -122.053721;
}
behavior CARL
{
  id = 110;
  lightSwitch = 1;
  fstop = 31;
  clipname = 1;
  duration = 1;
  record = 1;
}
#Three.  Descend.  
behavior waypoint
{
  duration = 319;
  depth = 100;
  speed = 1.5;
  latitude = 36.696678;
  longitude = -122.054729;
}
behavior CARL
{
  id = 108;
  duration = 1;
  record = 0;
  lightSwitch = 0;
  homeIris = 1;
}
#Two.  End Segment.
behavior waypoint
{
  duration = 877;
  depth = 50;
  speed = 1.1;
  latitude = 36.695867;
  longitude = -122.053721;
}
behavior CARL
{
  id = 104;
  fstop = 31;
  brightness = 90;
  lightSwitch = 1;
  clipname = 1;
  duration = 1;
  record = 1;
}
#One.  Start the Segment.
# 36 41.750  -122 2.990
behavior waypoint
{
 duration = 415;
 depth = 50;
 speed = 1.5;
 latitude = 36.695867;
 longitude = -122.049800;
}
#Zero.  Lead-in waypoint.
behavior waypoint
{
 duration = 1250;
 depth = 50;
 speed = 1.5;
 latitude = 36.696227;
 longitude = -122.048007;
}
#
# Descend and transit to starting waypoint.
behavior descend
{
horizontalMode = rudder;
horizontal = 3.0;
pitch = -35.000000;
speed = 1.500000;
maxDepth = 48;
minAltitude = 50.000000;
duration = 600;
}
behavior CARL
{
  id = 104;
  fstop = 31;
  brightness = 90;
  lightSwitch = 1;
  clipname = 1;
  duration = 1;
  record = 1;
}
#
# Descend and transit to starting waypoint.
behavior descend {
horizontalMode = heading;
horizontal = 60.0;
pitch = -30;
speed = 1.5;
maxDepth = 8;
duration = 400;
minAltitude = 30;
}
# setpoint on surface to gather momentum
behavior setpoint {
duration = 30;
heading = 60.0;
speed = 1.5;
verticalMode = pitch;
pitch = 0;
}
#
# Begin recording on the surface
#
behavior CARL
{
  id = 101;
  clipname = 1;
  record = 1;
  duration = 1;
  fstop = 561;
}
# acquire gps fix
behavior getgps {
duration = 300;
minHits = 10;
abortOnTimeout = True;
}
#
# Bring up the lights and close the iris since we're on the surface
#
behavior CARL
{
  id = 99;
  lightSwitch = 1;
  brightness = 90;
  duration = 1;
  homeIris = 1;
}
